==> Paws-0.02.tar.gz: Paws-0.02/lib/Paws/AutoScaling/DescribeLifecycleHookTypes.pm <==

package Paws::AutoScaling::DescribeLifecycleHookTypes {
  use Moose;

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeLifecycleHookTypes');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::AutoScaling::DescribeLifecycleHookTypesAnswer');
  class_has _result_key => (isa => 'Str', is => 'ro', default => 'DescribeLifecycleHookTypesResult');
}
1;

### main pod documentation begin ###

=head1 NAME

Paws::AutoScaling::DescribeLifecycleHookTypes - Arguments for method DescribeLifecycleHookTypes on Paws::AutoScaling

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeLifecycleHookTypes on the 
Auto Scaling service. Use the attributes of this class
as arguments to method DescribeLifecycleHookTypes.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to DescribeLifecycleHookTypes.

As an example:

  $service_obj->DescribeLifecycleHookTypes(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES



=head1 SEE ALSO

This class forms part of L<Paws>, and documents parameters for DescribeLifecycleHookTypes in Paws::AutoScaling

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.15.tar.gz: Paws-0.15/lib/Paws/AutoScaling/DescribeLifecycleHookTypes.pm <==

package Paws::AutoScaling::DescribeLifecycleHookTypes;
  use Moose;

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeLifecycleHookTypes');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::AutoScaling::DescribeLifecycleHookTypesAnswer');
  class_has _result_key => (isa => 'Str', is => 'ro', default => 'DescribeLifecycleHookTypesResult');
1;

### main pod documentation begin ###

=head1 NAME

Paws::AutoScaling::DescribeLifecycleHookTypes - Arguments for method DescribeLifecycleHookTypes on Paws::AutoScaling

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeLifecycleHookTypes on the 
Auto Scaling service. Use the attributes of this class
as arguments to method DescribeLifecycleHookTypes.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to DescribeLifecycleHookTypes.

As an example:

  $service_obj->DescribeLifecycleHookTypes(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribeLifecycleHookTypes in L<Paws::AutoScaling>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
